@@ -17,7 +17,10 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner", "1.67.9", __name__[0:-6], "cdk-gitlab-runner@1.67.9.jsii.tgz"
+    "cdk-gitlab-runner",
+    "1.67.10",
+    __name__[0:-6],
+    "cdk-gitlab-runner@1.67.10.jsii.tgz",
 )
 
 __all__ = [
